
Changelog
=========

v1.0.0dev
---------
- More fleshed-out interface to cosmoHammer, with base classes abstracting some common
  patterns.
- New likelihoods and cores that are able to work on any data from the ``21cmFAST`` pipeline.
- Better logging
- Better exception handling
- pip-installable
- Documentation
- Pipenv support
- Full code formatting applied
